@@ -4,6 +4,7 @@ Datasets
 
 A few popular time series datasets
 """
+
 from pathlib import Path
 from typing import List
 
@@ -63,6 +64,34 @@ class AusBeerDataset(DatasetLoaderCSV):
         )
 
 
+class AustralianTourismDataset(DatasetLoaderCSV):
+    """
+    A single multivariate TimeSeries, containing monthly tourism numbers over
+    36 months in Australia. The numbers are broken down per region
+    ("NSW", "VIC", "QLD", "SA", "WA", "TAS", "NT"), reason ("Hol", "VFR", "Bus", "Oth"),
+    (region, reason) pairs, and (region, reason, <city>) tuples, where <city>
+    can be either "city" or "noncity".
+
+    This is an augmented version of the Australian tourism dataset available in [1]_,
+    where we pre-computed the groupings per region (not available in the original dataset).
+
+    References
+    ----------
+    .. [1] https://robjhyndman.com/publications/hierarchical-tourism/
+    """
+
+    def __init__(self):
+        super().__init__(
+            metadata=DatasetLoaderMetadata(
+                "australian_tourism.csv",
+                uri=_DEFAULT_PATH + "/australian_tourism.csv",
+                hash="6eeea6b56e16e01123f303b492d9901c",
+                header_time=None,
+                format_time=None,
+            )
+        )
+
+
 class EnergyDataset(DatasetLoaderCSV):
     """
     Hourly energy dataset coming from [1]_.
