@@ -16,13 +16,15 @@ import numpy as np
 from statsmodels.tsa.arima.model import ARIMA as staARIMA
 
 from darts.logging import get_logger
-from darts.models.forecasting.forecasting_model import DualCovariatesForecastingModel
+from darts.models.forecasting.forecasting_model import (
+    TransferableDualCovariatesForecastingModel,
+)
 from darts.timeseries import TimeSeries
 
 logger = get_logger(__name__)
 
 
-class ARIMA(DualCovariatesForecastingModel):
+class ARIMA(TransferableDualCovariatesForecastingModel):
     def __init__(
         self,
         p: int = 12,
@@ -66,11 +68,14 @@ class ARIMA(DualCovariatesForecastingModel):
         return f"SARIMA{self.order}x{self.seasonal_order}"
 
     def _fit(self, series: TimeSeries, future_covariates: Optional[TimeSeries] = None):
-
         super()._fit(series, future_covariates)
+
+        # storing to restore the statsmodels model results object
+        self.training_historic_future_covariates = future_covariates
+
         m = staARIMA(
-            self.training_series.values(),
-            exog=future_covariates.values() if future_covariates else None,
+            series.values(copy=False),
+            exog=future_covariates.values(copy=False) if future_covariates else None,
             order=self.order,
             seasonal_order=self.seasonal_order,
             trend=self.trend,
@@ -82,6 +87,8 @@ class ARIMA(DualCovariatesForecastingModel):
     def _predict(
         self,
         n: int,
+        series: Optional[TimeSeries] = None,
+        historic_future_covariates: Optional[TimeSeries] = None,
         future_covariates: Optional[TimeSeries] = None,
         num_samples: int = 1,
     ) -> TimeSeries:
@@ -93,18 +100,43 @@ class ARIMA(DualCovariatesForecastingModel):
                 "your model."
             )
 
-        super()._predict(n, future_covariates, num_samples)
+        super()._predict(
+            n, series, historic_future_covariates, future_covariates, num_samples
+        )
+
+        # updating statsmodels results object state with the new ts and covariates
+        if series is not None:
+            self.model = self.model.apply(
+                series.values(copy=False),
+                exog=historic_future_covariates.values(copy=False)
+                if historic_future_covariates
+                else None,
+            )
 
         if num_samples == 1:
             forecast = self.model.forecast(
-                steps=n, exog=future_covariates.values() if future_covariates else None
+                steps=n,
+                exog=future_covariates.values(copy=False)
+                if future_covariates
+                else None,
             )
         else:
             forecast = self.model.simulate(
                 nsimulations=n,
                 repetitions=num_samples,
                 initial_state=self.model.states.predicted[-1, :],
-                exog=future_covariates.values() if future_covariates else None,
+                exog=future_covariates.values(copy=False)
+                if future_covariates
+                else None,
+            )
+
+        # restoring statsmodels results object state
+        if series is not None:
+            self.model = self.model.apply(
+                self._orig_training_series.values(copy=False),
+                exog=self.training_historic_future_covariates.values(copy=False)
+                if self.training_historic_future_covariates
+                else None,
             )
 
         return self._build_forecast_series(forecast)
