@@ -29,6 +29,7 @@ from typing import List, Optional, Sequence, Tuple, Union
 
 import numpy as np
 import pandas as pd
+from catboost import CatBoostRegressor
 from sklearn.linear_model import LinearRegression
 from sklearn.multioutput import MultiOutputRegressor
 
@@ -47,6 +48,7 @@ class RegressionModel(GlobalForecastingModel):
         lags_past_covariates: Union[int, List[int]] = None,
         lags_future_covariates: Union[Tuple[int, int], List[int]] = None,
         output_chunk_length: int = 1,
+        add_encoders: Optional[dict] = None,
         model=None,
     ):
         """Regression Model
@@ -70,6 +72,26 @@ class RegressionModel(GlobalForecastingModel):
             Number of time steps predicted at once by the internal regression model. Does not have to equal the forecast
             horizon `n` used in `predict()`. However, setting `output_chunk_length` equal to the forecast horizon may
             be useful if the covariates don't extend far enough into the future.
+        add_encoders
+            A large number of past and future covariates can be automatically generated with `add_encoders`.
+            This can be done by adding multiple pre-defined index encoders and/or custom user-made functions that
+            will be used as index encoders. Additionally, a transformer such as Darts' :class:`Scaler` can be added to
+            transform the generated covariates. This happens all under one hood and only needs to be specified at
+            model creation.
+            Read :meth:`SequentialEncoder <darts.utils.data.encoders.SequentialEncoder>` to find out more about
+            ``add_encoders``. Default: ``None``. An example showing some of ``add_encoders`` features:
+
+            .. highlight:: python
+            .. code-block:: python
+
+                add_encoders={
+                    'cyclic': {'future': ['month']},
+                    'datetime_attribute': {'future': ['hour', 'dayofweek']},
+                    'position': {'past': ['absolute'], 'future': ['relative']},
+                    'custom': {'past': [lambda idx: (idx.year - 1950) / 50]},
+                    'transformer': Scaler()
+                }
+            ..
         model
             Scikit-learn-like model with ``fit()`` and ``predict()`` methods. Also possible to use model that doesn't
             support multi-output regression for multivariate timeseries, in which case one regressor
@@ -77,7 +99,7 @@ class RegressionModel(GlobalForecastingModel):
             If None, defaults to: ``sklearn.linear_model.LinearRegression(n_jobs=-1)``.
         """
 
-        super().__init__()
+        super().__init__(add_encoders=add_encoders)
 
         self.model = model
         self.lags = {}
@@ -199,6 +221,46 @@ class RegressionModel(GlobalForecastingModel):
         )
         self.output_chunk_length = output_chunk_length
 
+    @property
+    def _model_encoder_settings(self) -> Tuple[int, int, bool, bool]:
+        lags_covariates = {
+            lag for key in ["past", "future"] for lag in self.lags.get(key, [])
+        }
+        if lags_covariates:
+            # for lags < 0 we need to take `n` steps backwards from past and/or historic future covariates
+            # for minimum lag = -1 -> steps_back_inclusive = 1
+            # inclusive means n steps back including the end of the target series
+            n_steps_back_inclusive = abs(min(min(lags_covariates), 0))
+            # for lags >= 0 we need to take `n` steps ahead from future covariates
+            # for maximum lag = 0 -> output_chunk_length = 1
+            # exclusive means n steps ahead after the last step of the target series
+            n_steps_ahead_exclusive = max(max(lags_covariates), 0) + 1
+            takes_past_covariates = "past" in self.lags
+            takes_future_covariates = "future" in self.lags
+        else:
+            n_steps_back_inclusive = 0
+            n_steps_ahead_exclusive = 0
+            takes_past_covariates = False
+            takes_future_covariates = False
+        return (
+            n_steps_back_inclusive,
+            n_steps_ahead_exclusive,
+            takes_past_covariates,
+            takes_future_covariates,
+        )
+
+    def _get_encoders_n(self, n):
+        """Returns the `n` encoder prediction steps specific to RegressionModels.
+        This will generate slightly more past covariates than the minimum requirement when using past and future
+        covariate lags simultaneously. This is because encoders were written for TorchForecastingModels where we only
+        needed `n` future covariates. For RegressionModel we need `n + max_future_lag`
+        """
+        _, n_steps_ahead, _, takes_future_covariates = self._model_encoder_settings
+        if not takes_future_covariates:
+            return n
+        else:
+            return n + (n_steps_ahead - 1)
+
     @property
     def min_train_series_length(self) -> int:
         return max(
@@ -318,6 +380,7 @@ class RegressionModel(GlobalForecastingModel):
         Function that fit the model. Deriving classes can override this method for adding additional parameters (e.g.,
         adding validation data), keeping the sanity checks on series performed by fit().
         """
+
         training_samples, training_labels = self._create_lagged_data(
             target_series, past_covariates, future_covariates, max_samples_per_ts
         )
@@ -360,6 +423,15 @@ class RegressionModel(GlobalForecastingModel):
         **kwargs
             Additional keyword arguments passed to the `fit` method of the model.
         """
+
+        self.encoders = self.initialize_encoders()
+        if self.encoders.encoding_available:
+            past_covariates, future_covariates = self.encoders.encode_train(
+                target=series,
+                past_covariate=past_covariates,
+                future_covariate=future_covariates,
+            )
+
         super().fit(
             series=series,
             past_covariates=past_covariates,
@@ -417,6 +489,15 @@ class RegressionModel(GlobalForecastingModel):
                     self.model = MultiOutputRegressor(
                         self.model, n_jobs=n_jobs_multioutput_wrapper
                     )
+                elif isinstance(self.model, CatBoostRegressor):
+                    if (
+                        self.model.get_params()["loss_function"]
+                        == "RMSEWithUncertainty"
+                    ):
+                        self.model = MultiOutputRegressor(
+                            self.model, n_jobs=n_jobs_multioutput_wrapper
+                        )
+
         # warn if n_jobs_multioutput_wrapper was provided but not used
         if (
             not isinstance(self.model, MultiOutputRegressor)
@@ -467,6 +548,14 @@ class RegressionModel(GlobalForecastingModel):
             logger,
         )
 
+        if self.encoders.encoding_available:
+            past_covariates, future_covariates = self.encoders.encode_inference(
+                n=self._get_encoders_n(n),
+                target=series,
+                past_covariate=past_covariates,
+                future_covariate=future_covariates,
+            )
+
         super().predict(n, series, past_covariates, future_covariates, num_samples)
 
         if series is None:
@@ -635,7 +724,7 @@ class RegressionModel(GlobalForecastingModel):
 
 class _LikelihoodMixin:
     """
-    A class containing functions supporting quantile and poisson regression, to be used as a mixin for some
+    A class containing functions supporting quantile, poisson and gaussian regression, to be used as a mixin for some
     `RegressionModel` subclasses.
     """
 
@@ -700,6 +789,67 @@ class _LikelihoodMixin:
 
         return sampled
 
+    def _predict_normal(self, x: np.ndarray, num_samples: int, **kwargs) -> np.ndarray:
+        """Method intended for CatBoost's RMSEWithUncertainty loss. Returns samples
+        computed from double-valued inputs [mean, variance].
+        X is of shape (n_series * n_samples, n_regression_features)
+        """
+        k = x.shape[0]
+
+        # model_output shape:
+        # if univariate & output_chunk_length = 1: (num_samples, 2)
+        # else: (2, num_samples, n_components * output_chunk_length)
+        # where the axis with 2 dims is mu, sigma
+        model_output = self.model.predict(x, **kwargs)
+        output_dim = len(model_output.shape)
+
+        # deterministic case: we return the mean only
+        if num_samples == 1:
+            # univariate & single-chunk output
+            if output_dim <= 2:
+                output_slice = model_output[:, 0]
+            else:
+                output_slice = model_output[0, :, :]
+
+            return output_slice.reshape(k, self.output_chunk_length, -1)
+
+        # probabilistic case
+        # univariate & single-chunk output
+        if output_dim <= 2:
+            # embedding well shaped 2D output into 3D
+            model_output = np.expand_dims(model_output, axis=0)
+
+        else:
+            # we transpose to get mu, sigma couples on last axis
+            # shape becomes: (n_components * output_chunk_length, num_samples, 2)
+            model_output = model_output.transpose()
+
+        return self._normal_sampling(model_output, num_samples)
+
+    def _normal_sampling(self, model_output: np.ndarray, n_samples: int) -> np.ndarray:
+        """Sampling method for CatBoost's [mean, variance] output.
+        model_output is of shape (n_components * output_chunk_length, n_samples, 2),
+        where the last 2 dimensions are mu and sigma.
+        """
+        shape = model_output.shape
+        chunk_len = self.output_chunk_length
+
+        # treating each component separately
+        mu_sigma_list = [model_output[i, :, :] for i in range(shape[0])]
+
+        list_of_samples = [
+            self._rng.normal(
+                mu_sigma[:, 0],  # mean vector
+                mu_sigma[:, 1],  # diagonal covariance matrix
+            )
+            for mu_sigma in mu_sigma_list
+        ]
+
+        samples_transposed = np.array(list_of_samples).transpose()
+        samples_reshaped = samples_transposed.reshape(n_samples, chunk_len, -1)
+
+        return samples_reshaped
+
     def _predict_poisson(self, x: np.ndarray, num_samples: int, **kwargs) -> np.ndarray:
         """
         X is of shape (n_series * n_samples, n_regression_features)
