@@ -42,11 +42,21 @@ except ImportError:
     TORCH_AVAILABLE = False
 
 
+def get_dummy_series(
+    ts_length: int, lt_end_value: int = 10, st_value_offset: int = 10
+) -> TimeSeries:
+    return (
+        lt(length=ts_length, end_value=lt_end_value)
+        + st(length=ts_length, value_y_offset=st_value_offset)
+        + rt(length=ts_length)
+    )
+
+
 def compare_best_against_random(model_class, params, series, stride=1):
 
     # instantiate best model in expanding window mode
     np.random.seed(1)
-    best_model_1, _ = model_class.gridsearch(
+    best_model_1, _, _ = model_class.gridsearch(
         params,
         series,
         forecast_horizon=10,
@@ -57,7 +67,9 @@ def compare_best_against_random(model_class, params, series, stride=1):
 
     # instantiate best model in split mode
     train, val = series.split_before(series.time_index[-10])
-    best_model_2, _ = model_class.gridsearch(params, train, val_series=val, metric=mape)
+    best_model_2, _, _ = model_class.gridsearch(
+        params, train, val_series=val, metric=mape
+    )
 
     # intantiate model with random parameters from 'params'
     random.seed(1)
@@ -103,6 +115,26 @@ class BacktestingTestCase(DartsBaseTestClass):
         )
         self.assertEqual(score, 1.0)
 
+        # very large train length should not affect the backtest
+        score = NaiveDrift().backtest(
+            linear_series,
+            train_length=10000,
+            start=pd.Timestamp("20000201"),
+            forecast_horizon=3,
+            metric=r2_score,
+        )
+        self.assertEqual(score, 1.0)
+
+        # window of size 2 is too small for naive drift
+        with self.assertRaises(ValueError):
+            NaiveDrift().backtest(
+                linear_series,
+                train_length=2,
+                start=pd.Timestamp("20000201"),
+                forecast_horizon=3,
+                metric=r2_score,
+            )
+
         # test that it also works for time series that are not Datetime-indexed
         score = NaiveDrift().backtest(
             linear_series_int, start=0.7, forecast_horizon=3, metric=r2_score
@@ -136,6 +168,9 @@ class BacktestingTestCase(DartsBaseTestClass):
         NaiveDrift().backtest(linear_series, start=30)
         NaiveDrift().backtest(linear_series, start=0.7, overlap_end=True)
 
+        # Set custom train window length
+        NaiveDrift().backtest(linear_series, train_length=10, start=30)
+
         # Using invalid start and/or forecast_horizon values
         with self.assertRaises(ValueError):
             NaiveDrift().backtest(linear_series, start=0.7, forecast_horizon=-1)
@@ -148,6 +183,12 @@ class BacktestingTestCase(DartsBaseTestClass):
             NaiveDrift().backtest(linear_series, start=1.2)
         with self.assertRaises(TypeError):
             NaiveDrift().backtest(linear_series, start="wrong type")
+        with self.assertRaises(ValueError):
+            NaiveDrift().backtest(linear_series, train_length=0, start=0.5)
+        with self.assertRaises(TypeError):
+            NaiveDrift().backtest(linear_series, train_length=1.2, start=0.5)
+        with self.assertRaises(TypeError):
+            NaiveDrift().backtest(linear_series, train_length="wrong type", start=0.5)
 
         with self.assertRaises(ValueError):
             NaiveDrift().backtest(
@@ -230,6 +271,20 @@ class BacktestingTestCase(DartsBaseTestClass):
         )
         self.assertGreater(score, 0.9)
 
+        # univariate feature test + train length
+        score = LinearRegressionModel(
+            lags=None, lags_future_covariates=[0, -1]
+        ).backtest(
+            series=target,
+            future_covariates=features,
+            start=pd.Timestamp("20000201"),
+            train_length=20,
+            forecast_horizon=3,
+            metric=r2_score,
+            last_points_only=True,
+        )
+        self.assertGreater(score, 0.9)
+
         # Using an int or float value for start
         score = RandomForest(
             lags=12, lags_future_covariates=[0], random_state=0
@@ -280,6 +335,39 @@ class BacktestingTestCase(DartsBaseTestClass):
         )
         self.assertGreater(score, 0.94)
 
+        # multivariate feature test with train window 35
+        score_35 = RandomForest(
+            lags=12, lags_future_covariates=[0, -1], random_state=0
+        ).backtest(
+            series=target,
+            train_length=35,
+            future_covariates=features_multivariate,
+            start=pd.Timestamp("20000201"),
+            forecast_horizon=3,
+            metric=r2_score,
+        )
+        logger.info(
+            "Score for multivariate feature test with train window 35 is: ", score_35
+        )
+        self.assertGreater(score_35, 0.92)
+
+        # multivariate feature test with train window 45
+        score_45 = RandomForest(
+            lags=12, lags_future_covariates=[0, -1], random_state=0
+        ).backtest(
+            series=target,
+            train_length=45,
+            future_covariates=features_multivariate,
+            start=pd.Timestamp("20000201"),
+            forecast_horizon=3,
+            metric=r2_score,
+        )
+        logger.info(
+            "Score for multivariate feature test with train window 45 is: ", score_45
+        )
+        self.assertGreater(score_45, 0.94)
+        self.assertGreater(score_45, score_35)
+
         # multivariate with stride
         score = RandomForest(
             lags=12, lags_future_covariates=[0], random_state=0
@@ -297,12 +385,7 @@ class BacktestingTestCase(DartsBaseTestClass):
     def test_gridsearch(self):
         np.random.seed(1)
 
-        ts_length = 50
-        dummy_series = (
-            lt(length=ts_length, end_value=10)
-            + st(length=ts_length, value_y_offset=10)
-            + rt(length=ts_length)
-        )
+        dummy_series = get_dummy_series(ts_length=50)
         dummy_series_int_index = TimeSeries.from_values(dummy_series.values())
 
         theta_params = {"theta": list(range(3, 10))}
@@ -322,16 +405,34 @@ class BacktestingTestCase(DartsBaseTestClass):
             compare_best_against_random(ExponentialSmoothing, es_params, dummy_series)
         )
 
+    def test_gridsearch_metric_score(self):
+        np.random.seed(1)
+
+        model_class = Theta
+        params = {"theta": list(range(3, 6))}
+        dummy_series = get_dummy_series(ts_length=50)
+
+        best_model, _, score = model_class.gridsearch(
+            params,
+            series=dummy_series,
+            forecast_horizon=10,
+            stride=1,
+            start=dummy_series.time_index[-21],
+        )
+        recalculated_score = best_model.backtest(
+            series=dummy_series,
+            start=dummy_series.time_index[-21],
+            forecast_horizon=10,
+            stride=1,
+        )
+
+        self.assertEqual(score, recalculated_score, "The metric scores should match")
+
     @unittest.skipUnless(TORCH_AVAILABLE, "requires torch")
     def test_gridsearch_random_search(self):
         np.random.seed(1)
 
-        ts_length = 50
-        dummy_series = (
-            lt(length=ts_length, end_value=10)
-            + st(length=ts_length, value_y_offset=10)
-            + rt(length=ts_length)
-        )
+        dummy_series = get_dummy_series(ts_length=50)
 
         param_range = list(range(10, 20))
         params = {"lags": param_range}
@@ -343,16 +444,12 @@ class BacktestingTestCase(DartsBaseTestClass):
 
         self.assertEqual(type(result[0]), RandomForest)
         self.assertEqual(type(result[1]["lags"]), int)
+        self.assertEqual(type(result[2]), float)
         self.assertTrue(min(param_range) <= result[1]["lags"] <= max(param_range))
 
     @unittest.skipUnless(TORCH_AVAILABLE, "requires torch")
     def test_gridsearch_n_random_samples_bad_arguments(self):
-        ts_length = 50
-        dummy_series = (
-            lt(length=ts_length, end_value=10)
-            + st(length=ts_length, value_y_offset=10)
-            + rt(length=ts_length)
-        )
+        dummy_series = get_dummy_series(ts_length=50)
 
         params = {"lags": list(range(1, 11)), "past_covariates": list(range(1, 11))}
 
@@ -398,16 +495,11 @@ class BacktestingTestCase(DartsBaseTestClass):
         """
 
         np.random.seed(1)
-        ts_length = 100
 
-        dummy_series = (
-            lt(length=ts_length, end_value=1)
-            + st(length=ts_length, value_y_offset=0)
-            + rt(length=ts_length)
+        dummy_series = get_dummy_series(
+            ts_length=100, lt_end_value=1, st_value_offset=0
         ).astype(np.float32)
-
-        ts_train = dummy_series[: round(ts_length * 0.8)]
-        ts_val = dummy_series[round(ts_length * 0.8) :]
+        ts_train, ts_val = dummy_series.split_before(split_point=0.8)
 
         test_cases = [
             {
@@ -433,12 +525,12 @@ class BacktestingTestCase(DartsBaseTestClass):
             parameters = test["parameters"]
 
             np.random.seed(1)
-            _, best_params1 = model.gridsearch(
+            _, best_params1, _ = model.gridsearch(
                 parameters=parameters, series=ts_train, val_series=ts_val, n_jobs=1
             )
 
             np.random.seed(1)
-            _, best_params2 = model.gridsearch(
+            _, best_params2, _ = model.gridsearch(
                 parameters=parameters, series=ts_train, val_series=ts_val, n_jobs=-1
             )
 
